# Application Total Cost of Ownership (TCO) Extension
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/application-total-cost-of-ownership-extension#overview)
  * [Activating the Extension](https://help.sap.com/docs/leanix/ea/application-total-cost-of-ownership-extension#activating-the-extension)
  * [Meta Model Additions](https://help.sap.com/docs/leanix/ea/application-total-cost-of-ownership-extension#meta-model-additions)


Gain transparency into total cost of ownership with the extension that activates dedicated fields, calculations, as well as options for reports and KPIs for dashboards.
Collect and allocate cost data for applications and use cost data as a key datapoint in your IT landscape. The application total cost of ownership (TCO) extension is a set of complementary features for cost management: Cost-specific fields, calculations, new options for the landscape reports, and new KPIs on the executive dashboard. These tools bring transparency on total cost of ownership of applications and empower rationalization decisions.
